@@ -10,7 +10,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.1.6"
+version = "1.1.7"
 global log
 global anon
 anon = "tor"
@@ -179,10 +179,62 @@ class ip:
         res2=url + " : " + str(ip)
         print(a, "┌──────────[Domain Ip]")
         print(a, "└ "+url[7:] + " : " + str(ip))
+    def telegram(data=False):
+        import requests
+        infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+        infi_ip = infinity["ip"]
+        infi_port = infinity["port"]
+        socks_ip = infinity["socksip"]
+        socks_port = infinity["socksport"]
+        if data:
+           get = requests.get("https://api.proxyscrape.com/v2/?request=displayproxies&protocol=http&timeout=150")
+           done = False
+           def animate():
+               for c in itertools.cycle(["⢿", "⣻", "⣽", "⣾", "⣷", "⣯", "⣟", "⡿"]):
+                   if done:
+                       break
+                   sys.stdout.write('\r\x1B[32mParsing proxy ' + c + '\x1B[37m\r')
+                   sys.stdout.flush()
+                   time.sleep(0.07)
+           t = threading.Thread(target=animate)
+           t.start()
+           time.sleep(2)
+           done = True
+           print("Proxies http(s)")
+           print(infi_ip+":"+infi_port)
+           print(get.text)
+        else:
+           get = requests.get("https://api.proxyscrape.com/v2/?request=displayproxies&protocol=socks5&timeout=250")
+           done = False
+           def animate():
+               for c in itertools.cycle(["⢿", "⣻", "⣽", "⣾", "⣷", "⣯", "⣟", "⡿"]):
+                   if done:
+                       break
+                   sys.stdout.write('\r\x1B[32mParsing proxy ' + c + '\x1B[37m\r')
+                   sys.stdout.flush()
+                   time.sleep(0.07)
+           t = threading.Thread(target=animate)
+           t.start()
+           time.sleep(2)
+           done = True
+           print("Proxies Socks5")
+           print(socks_ip+":"+socks_port)
+           print(get.text)
     def proxy(data=False):
+        import requests
+        infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+        infi_ip = infinity["ip"]
+        infi_port = infinity["port"]
+        proxis = infi_ip+":"+infi_port
         if data:
-           proxy_list = pyproxify.fetch(count=7, google=True, https=True)
            proxy = []
+           proxy.append(proxis)
+           proxy_list = pyproxify.fetch(count=7, google=True, https=True)
+           for item in proxy_list:
+              ip = item["ip"]
+              port = item["port"]
+              proxy.append(ip+":"+port)
+           proxy_list = pyproxify.fetch(count=8, https=True)
            for item in proxy_list:
               ip = item["ip"]
               port = item["port"]
@@ -202,6 +254,13 @@ class ip:
            t.start()
            time.sleep(2)
            done = True
+           print("\nIp         : "+infi_ip)
+           print("Port       : "+infi_port)
+           print("Https      : True")
+           print("Google     : True")
+           print("Country    : Randomized")
+           print("Checked    : Infinite")
+           print("Anonymity  : Tor\n")
            proxy_list = pyproxify.fetch(count=3, google=True, https=True)
            for item in proxy_list:
               ip = item["ip"]
@@ -212,13 +271,28 @@ class ip:
               c_name = country["name"]
               print("Ip         : "+ip)
               print("Port       : "+port)
-              print("Http       : True")
               print("Https      : False")
               print("Google     : True")
               print("Country    : "+c_name)
               print("Checked    : "+last)
               print("Anonymity  : "+anonymity)
               print(" ")
+           proxy_list = pyproxify.fetch(count=2, google=False, https=True)
+           for item in proxy_list:
+              ip = item["ip"]
+              port = item["port"]
+              last = item["last_update"]
+              anonymity = item["anonymity"]
+              country = item["country"]
+              c_name = country["name"]
+              print("Ip         : "+ip)
+              print("Port       : "+port)
+              print("Https      : False")
+              print("Google     : False")
+              print("Country    : "+c_name)
+              print("Checked    : "+last)
+              print("Anonymity  : "+anonymity)
+              print(" ")
 class check:
     def proxy(ip, port):
         import requests
@@ -284,7 +358,7 @@ class inquiry:
                  if log:
                      print("[8%] Importing proxy list")
                      print("[25%] Proxy type http(s)")
-                 proxy_list = pyproxify.fetch(count=1, google=True, https=True)
+                 proxy_list = pyproxify.fetch(count=1, https=True)
                  for item in proxy_list:
                      ip = item["ip"]
                      port = item["port"]
@@ -311,11 +385,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     proxy_list = pyproxify.fetch(count=2, google=True, https=True)
-                     for item in proxy_list:
-                         ip = item["ip"]
-                         port = item["port"]
-                         proxy = ip+":"+port
+                     ip = "6.tcp.eu.ngrok.io"
+                     port = "10882"
+                     proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
@@ -323,9 +395,7 @@ class inquiry:
                      with eventlet.Timeout(10) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             args = " ".join([str(m) for m in args])
-                             url = args.replace("https", "http")
-                             get = ss.get(url, **kwargs, headers={"User-Agent": ua.windows()})
+                             get = ss.get(args, **kwargs, headers={"User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
                              return get
@@ -350,7 +420,8 @@ class inquiry:
                     print("[100%] Success")
                 return get
             except:
-                return '\033[91mUnknown error\x1B[37m'
+                code = get.status_code
+                return '\033[91m'+code+'\x1B[37m'
     def post(*args, **kwargs):
         if anon == "tor" or anon == "web":
             if anon == "web":
@@ -396,7 +467,7 @@ class inquiry:
                  if log:
                      print("[8%] Importing proxy list")
                      print("[25%] Proxy type http(s)")
-                 proxy_list = pyproxify.fetch(count=1, google=True, https=True)
+                 proxy_list = pyproxify.fetch(count=1, https=True)
                  for item in proxy_list:
                      ip = item["ip"]
                      port = item["port"]
@@ -423,11 +494,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     proxy_list = pyproxify.fetch(count=2, google=True, https=True)
-                     for item in proxy_list:
-                         ip = item["ip"]
-                         port = item["port"]
-                         proxy = ip+":"+port
+                     ip = "6.tcp.eu.ngrok.io"
+                     port = "10882"
+                     proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
@@ -435,9 +504,7 @@ class inquiry:
                      with eventlet.Timeout(10) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             args = " ".join([str(m) for m in args])
-                             url = args.replace("https", "http")
-                             post = ss.post(url, **kwargs, headers={"User-Agent": ua.windows()})
+                             post = ss.post(args, **kwargs, headers={"User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
                              return post
@@ -488,7 +555,7 @@ class inquiry:
                  if log:
                      print("[8%] Importing proxy list")
                      print("[25%] Proxy type http(s)")
-                 proxy_list = pyproxify.fetch(count=1, google=True, https=True)
+                 proxy_list = pyproxify.fetch(count=1, https=True)
                  for item in proxy_list:
                      ip = item["ip"]
                      port = item["port"]
@@ -580,7 +647,7 @@ class inquiry:
                  if log:
                      print("[8%] Importing proxy list")
                      print("[25%] Proxy type http(s)")
-                 proxy_list = pyproxify.fetch(count=1, google=True, https=True)
+                 proxy_list = pyproxify.fetch(count=1, https=True)
                  for item in proxy_list:
                      ip = item["ip"]
                      port = item["port"]
@@ -672,7 +739,7 @@ class inquiry:
                  if log:
                      print("[8%] Importing proxy list")
                      print("[25%] Proxy type http(s)")
-                 proxy_list = pyproxify.fetch(count=1, google=True, https=True)
+                 proxy_list = pyproxify.fetch(count=1, https=True)
                  for item in proxy_list:
                      ip = item["ip"]
                      port = item["port"]
